@@ -20,24 +20,31 @@ static cmdp_token tokens_FLOATING_MINIMUM_SIZE_WIDTH[1] = {
 static cmdp_token tokens_BAR_BINDING_MODE_INDICATOR[1] = {
     { "word", "value", __CALL, { 4 } },
 };
+static cmdp_token tokens_BAR_WORKSPACE_MIN_WIDTH_PX[2] = {
+    { "'px", "", BAR_WORKSPACE_MIN_WIDTH_PX, { 0 } },
+    { "end", "", __CALL, { 5 } },
+};
 static cmdp_token tokens_FOCUS_ON_WINDOW_ACTIVATION[1] = {
-    { "word", "mode", __CALL, { 5 } },
+    { "word", "mode", __CALL, { 6 } },
 };
 static cmdp_token tokens_FORCE_DISPLAY_URGENCY_HINT[1] = {
     { "number", "duration_ms", FORCE_DISPLAY_URGENCY_HINT_MS, { 0 } },
 };
 static cmdp_token tokens_BAR_STRIP_WORKSPACE_NAME[1] = {
-    { "word", "value", __CALL, { 6 } },
+    { "word", "value", __CALL, { 7 } },
 };
 static cmdp_token tokens_DEFAULT_BORDER_PIXELS_PX[2] = {
     { "'px", "", DEFAULT_BORDER_PIXELS_PX, { 0 } },
-    { "end", "", __CALL, { 7 } },
+    { "end", "", __CALL, { 8 } },
 };
 static cmdp_token tokens_WORKSPACE_BACK_AND_FORTH[1] = {
-    { "word", "value", __CALL, { 8 } },
+    { "word", "value", __CALL, { 9 } },
 };
 static cmdp_token tokens_ASSIGN_WORKSPACE_NUMBER[1] = {
-    { "string", "number", __CALL, { 9 } },
+    { "string", "number", __CALL, { 10 } },
+};
+static cmdp_token tokens_BAR_WORKSPACE_MIN_WIDTH[1] = {
+    { "number", "width", BAR_WORKSPACE_MIN_WIDTH_PX, { 0 } },
 };
 static cmdp_token tokens_FLOATING_MAXIMUM_SIZE_X[1] = {
     { "'x", "", FLOATING_MAXIMUM_SIZE_HEIGHT, { 0 } },
@@ -46,9 +53,9 @@ static cmdp_token tokens_FLOATING_MINIMUM_SIZE_X[1] = {
     { "'x", "", FLOATING_MINIMUM_SIZE_HEIGHT, { 0 } },
 };
 static cmdp_token tokens_POPUP_DURING_FULLSCREEN[3] = {
-    { "'ignore", "value", __CALL, { 10 } },
-    { "'leave_fullscreen", "value", __CALL, { 11 } },
-    { "'smart", "value", __CALL, { 12 } },
+    { "'ignore", "value", __CALL, { 11 } },
+    { "'leave_fullscreen", "value", __CALL, { 12 } },
+    { "'smart", "value", __CALL, { 13 } },
 };
 static cmdp_token tokens_BAR_COLORS_IGNORE_LINE[1] = {
     { "line", "", BAR_COLORS, { 0 } },
@@ -57,56 +64,56 @@ static cmdp_token tokens_BAR_COLORS_BACKGROUND[1] = {
     { "word", "background", BAR_COLORS_TEXT, { 0 } },
 };
 static cmdp_token tokens_BAR_WORKSPACE_BUTTONS[1] = {
-    { "word", "value", __CALL, { 13 } },
+    { "word", "value", __CALL, { 14 } },
 };
 static cmdp_token tokens_DEFAULT_BORDER_PIXELS[2] = {
-    { "end", "", __CALL, { 14 } },
+    { "end", "", __CALL, { 15 } },
     { "number", "width", DEFAULT_BORDER_PIXELS_PX, { 0 } },
 };
 static cmdp_token tokens_WORKSPACE_OUTPUT_WORD[2] = {
-    { "word", "output", __CALL, { 15 } },
+    { "word", "output", __CALL, { 16 } },
     { "end", "", INITIAL, { 0 } },
 };
 static cmdp_token tokens_BAR_SEPARATOR_SYMBOL[1] = {
-    { "string", "separator", __CALL, { 16 } },
+    { "string", "separator", __CALL, { 17 } },
 };
 static cmdp_token tokens_FORCE_FOCUS_WRAPPING[1] = {
-    { "word", "value", __CALL, { 17 } },
+    { "word", "value", __CALL, { 18 } },
 };
 static cmdp_token tokens_BAR_BINDSYM_COMMAND[2] = {
     { "'--release", "release", BAR_BINDSYM_COMMAND, { 0 } },
-    { "string", "command", __CALL, { 18 } },
+    { "string", "command", __CALL, { 19 } },
 };
 static cmdp_token tokens_BAR_TRAY_PADDING_PX[2] = {
     { "'px", "", BAR_TRAY_PADDING_PX, { 0 } },
-    { "end", "", __CALL, { 19 } },
+    { "end", "", __CALL, { 20 } },
 };
 static cmdp_token tokens_DEFAULT_ORIENTATION[3] = {
-    { "'horizontal", "orientation", __CALL, { 20 } },
-    { "'vertical", "orientation", __CALL, { 21 } },
-    { "'auto", "orientation", __CALL, { 22 } },
+    { "'horizontal", "orientation", __CALL, { 21 } },
+    { "'vertical", "orientation", __CALL, { 22 } },
+    { "'auto", "orientation", __CALL, { 23 } },
 };
 static cmdp_token tokens_FOCUS_FOLLOWS_MOUSE[1] = {
-    { "word", "value", __CALL, { 23 } },
+    { "word", "value", __CALL, { 24 } },
 };
 static cmdp_token tokens_BAR_STATUS_COMMAND[1] = {
-    { "string", "command", __CALL, { 24 } },
-};
-static cmdp_token tokens_BAR_WHEEL_DOWN_CMD[1] = {
     { "string", "command", __CALL, { 25 } },
 };
+static cmdp_token tokens_BAR_WHEEL_DOWN_CMD[1] = {
+    { "string", "command", __CALL, { 26 } },
+};
 static cmdp_token tokens_COLOR_CHILD_BORDER[2] = {
-    { "word", "child_border", __CALL, { 26 } },
-    { "end", "", __CALL, { 27 } },
+    { "word", "child_border", __CALL, { 27 } },
+    { "end", "", __CALL, { 28 } },
 };
 static cmdp_token tokens_FOR_WINDOW_COMMAND[1] = {
-    { "string", "command", __CALL, { 28 } },
+    { "string", "command", __CALL, { 29 } },
 };
 static cmdp_token tokens_BAR_COLORS_BORDER[1] = {
     { "word", "border", BAR_COLORS_BACKGROUND, { 0 } },
 };
 static cmdp_token tokens_BAR_COLORS_SINGLE[1] = {
-    { "word", "color", __CALL, { 29 } },
+    { "word", "color", __CALL, { 30 } },
 };
 static cmdp_token tokens_FLOATING_MODIFIER[10] = {
     { "'Mod1", "modifiers", FLOATING_MODIFIER, { 0 } },
@@ -118,130 +125,131 @@ static cmdp_token tokens_FLOATING_MODIFIER[10] = {
     { "'Control", "modifiers", FLOATING_MODIFIER, { 0 } },
     { "'Ctrl", "modifiers", FLOATING_MODIFIER, { 0 } },
     { "'+", "", FLOATING_MODIFIER, { 0 } },
-    { "end", "", __CALL, { 30 } },
+    { "end", "", __CALL, { 31 } },
 };
 static cmdp_token tokens_HIDE_EDGE_BORDERS[11] = {
-    { "'none", "hide_borders", __CALL, { 31 } },
-    { "'vertical", "hide_borders", __CALL, { 32 } },
-    { "'horizontal", "hide_borders", __CALL, { 33 } },
-    { "'both", "hide_borders", __CALL, { 34 } },
-    { "'smart", "hide_borders", __CALL, { 35 } },
-    { "'1", "hide_borders", __CALL, { 36 } },
-    { "'yes", "hide_borders", __CALL, { 37 } },
-    { "'true", "hide_borders", __CALL, { 38 } },
-    { "'on", "hide_borders", __CALL, { 39 } },
-    { "'enable", "hide_borders", __CALL, { 40 } },
-    { "'active", "hide_borders", __CALL, { 41 } },
+    { "'none", "hide_borders", __CALL, { 32 } },
+    { "'vertical", "hide_borders", __CALL, { 33 } },
+    { "'horizontal", "hide_borders", __CALL, { 34 } },
+    { "'both", "hide_borders", __CALL, { 35 } },
+    { "'smart", "hide_borders", __CALL, { 36 } },
+    { "'1", "hide_borders", __CALL, { 37 } },
+    { "'yes", "hide_borders", __CALL, { 38 } },
+    { "'true", "hide_borders", __CALL, { 39 } },
+    { "'on", "hide_borders", __CALL, { 40 } },
+    { "'enable", "hide_borders", __CALL, { 41 } },
+    { "'active", "hide_borders", __CALL, { 42 } },
 };
 static cmdp_token tokens_ASSIGN_WORKSPACE[5] = {
     { "'→", "", ASSIGN_WORKSPACE, { 0 } },
     { "'output", "", ASSIGN_OUTPUT, { 0 } },
     { "'workspace", "", ASSIGN_WORKSPACE, { 0 } },
     { "'number", "", ASSIGN_WORKSPACE_NUMBER, { 0 } },
-    { "string", "workspace", __CALL, { 42 } },
+    { "string", "workspace", __CALL, { 43 } },
 };
 static cmdp_token tokens_BAR_COLORS_BRACE[2] = {
     { "end", "", BAR_COLORS_BRACE, { 0 } },
     { "'{", "", BAR_COLORS, { 0 } },
 };
 static cmdp_token tokens_BAR_HIDDEN_STATE[2] = {
-    { "'hide", "hidden_state", __CALL, { 43 } },
-    { "'show", "hidden_state", __CALL, { 44 } },
+    { "'hide", "hidden_state", __CALL, { 44 } },
+    { "'show", "hidden_state", __CALL, { 45 } },
 };
 static cmdp_token tokens_BAR_TRAY_PADDING[1] = {
     { "number", "padding_px", BAR_TRAY_PADDING_PX, { 0 } },
 };
 static cmdp_token tokens_BAR_WHEEL_UP_CMD[1] = {
-    { "string", "command", __CALL, { 45 } },
+    { "string", "command", __CALL, { 46 } },
 };
 static cmdp_token tokens_COLOR_BACKGROUND[1] = {
     { "word", "background", COLOR_TEXT, { 0 } },
 };
 static cmdp_token tokens_IPC_KILL_TIMEOUT[1] = {
-    { "number", "timeout", __CALL, { 46 } },
+    { "number", "timeout", __CALL, { 47 } },
 };
 static cmdp_token tokens_MODE_BINDCOMMAND[5] = {
     { "'--release", "release", MODE_BINDCOMMAND, { 0 } },
     { "'--border", "border", MODE_BINDCOMMAND, { 0 } },
     { "'--whole-window", "whole_window", MODE_BINDCOMMAND, { 0 } },
     { "'--exclude-titlebar", "exclude_titlebar", MODE_BINDCOMMAND, { 0 } },
-    { "string", "command", __CALL, { 47 } },
+    { "string", "command", __CALL, { 48 } },
 };
 static cmdp_token tokens_MODE_IGNORE_LINE[1] = {
     { "line", "", MODE, { 0 } },
 };
 static cmdp_token tokens_WORKSPACE_LAYOUT[4] = {
-    { "'default", "layout", __CALL, { 48 } },
-    { "'stacking", "layout", __CALL, { 49 } },
-    { "'stacked", "layout", __CALL, { 50 } },
-    { "'tabbed", "layout", __CALL, { 51 } },
+    { "'default", "layout", __CALL, { 49 } },
+    { "'stacking", "layout", __CALL, { 50 } },
+    { "'stacked", "layout", __CALL, { 51 } },
+    { "'tabbed", "layout", __CALL, { 52 } },
 };
 static cmdp_token tokens_WORKSPACE_OUTPUT[1] = {
     { "'output", "", WORKSPACE_OUTPUT_WORD, { 0 } },
 };
 static cmdp_token tokens_BAR_BAR_COMMAND[1] = {
-    { "string", "command", __CALL, { 52 } },
+    { "string", "command", __CALL, { 53 } },
 };
 static cmdp_token tokens_BAR_COLORS_TEXT[2] = {
-    { "end", "", __CALL, { 53 } },
-    { "word", "text", __CALL, { 54 } },
+    { "end", "", __CALL, { 54 } },
+    { "word", "text", __CALL, { 55 } },
 };
 static cmdp_token tokens_BAR_IGNORE_LINE[1] = {
     { "line", "", BAR, { 0 } },
 };
 static cmdp_token tokens_BAR_SOCKET_PATH[1] = {
-    { "string", "path", __CALL, { 55 } },
+    { "string", "path", __CALL, { 56 } },
 };
 static cmdp_token tokens_BAR_TRAY_OUTPUT[1] = {
-    { "word", "output", __CALL, { 56 } },
+    { "word", "output", __CALL, { 57 } },
 };
 static cmdp_token tokens_COLOR_INDICATOR[2] = {
     { "word", "indicator", COLOR_CHILD_BORDER, { 0 } },
-    { "end", "", __CALL, { 57 } },
+    { "end", "", __CALL, { 58 } },
 };
 static cmdp_token tokens_DISABLE_RANDR15[1] = {
-    { "word", "value", __CALL, { 58 } },
+    { "word", "value", __CALL, { 59 } },
 };
 static cmdp_token tokens_DEFAULT_BORDER[4] = {
     { "'normal", "border", DEFAULT_BORDER_PIXELS, { 0 } },
     { "'pixel", "border", DEFAULT_BORDER_PIXELS, { 0 } },
-    { "'1pixel", "border", __CALL, { 59 } },
-    { "'none", "border", __CALL, { 60 } },
+    { "'1pixel", "border", __CALL, { 60 } },
+    { "'none", "border", __CALL, { 61 } },
 };
-static cmdp_token tokens_FOCUS_WRAPPING[13] = {
-    { "'1", "value", __CALL, { 61 } },
-    { "'yes", "value", __CALL, { 62 } },
-    { "'true", "value", __CALL, { 63 } },
-    { "'on", "value", __CALL, { 64 } },
-    { "'enable", "value", __CALL, { 65 } },
-    { "'active", "value", __CALL, { 66 } },
-    { "'0", "value", __CALL, { 67 } },
-    { "'no", "value", __CALL, { 68 } },
-    { "'false", "value", __CALL, { 69 } },
-    { "'off", "value", __CALL, { 70 } },
-    { "'disable", "value", __CALL, { 71 } },
-    { "'inactive", "value", __CALL, { 72 } },
-    { "'force", "value", __CALL, { 73 } },
+static cmdp_token tokens_FOCUS_WRAPPING[14] = {
+    { "'1", "value", __CALL, { 62 } },
+    { "'yes", "value", __CALL, { 63 } },
+    { "'true", "value", __CALL, { 64 } },
+    { "'on", "value", __CALL, { 65 } },
+    { "'enable", "value", __CALL, { 66 } },
+    { "'active", "value", __CALL, { 67 } },
+    { "'0", "value", __CALL, { 68 } },
+    { "'no", "value", __CALL, { 69 } },
+    { "'false", "value", __CALL, { 70 } },
+    { "'off", "value", __CALL, { 71 } },
+    { "'disable", "value", __CALL, { 72 } },
+    { "'inactive", "value", __CALL, { 73 } },
+    { "'force", "value", __CALL, { 74 } },
+    { "'workspace", "value", __CALL, { 75 } },
 };
 static cmdp_token tokens_FORCE_XINERAMA[1] = {
-    { "word", "value", __CALL, { 74 } },
+    { "word", "value", __CALL, { 76 } },
 };
 static cmdp_token tokens_ASSIGN_OUTPUT[1] = {
-    { "string", "output", __CALL, { 75 } },
+    { "string", "output", __CALL, { 77 } },
 };
 static cmdp_token tokens_CRITERION_STR[1] = {
-    { "word", "cvalue", __CALL, { 76 } },
+    { "word", "cvalue", __CALL, { 78 } },
 };
 static cmdp_token tokens_MOUSE_WARPING[2] = {
-    { "'none", "value", __CALL, { 77 } },
-    { "'output", "value", __CALL, { 78 } },
+    { "'none", "value", __CALL, { 79 } },
+    { "'output", "value", __CALL, { 80 } },
 };
 static cmdp_token tokens_RESTART_STATE[1] = {
-    { "string", "path", __CALL, { 79 } },
+    { "string", "path", __CALL, { 81 } },
 };
 static cmdp_token tokens_BAR_MODIFIER[12] = {
-    { "'off", "", __CALL, { 80 } },
-    { "'none", "", __CALL, { 81 } },
+    { "'off", "", __CALL, { 82 } },
+    { "'none", "", __CALL, { 83 } },
     { "'Mod1", "modifiers", BAR_MODIFIER, { 0 } },
     { "'Mod2", "modifiers", BAR_MODIFIER, { 0 } },
     { "'Mod3", "modifiers", BAR_MODIFIER, { 0 } },
@@ -251,20 +259,20 @@ static cmdp_token tokens_BAR_MODIFIER[12] = {
     { "'Control", "modifiers", BAR_MODIFIER, { 0 } },
     { "'Ctrl", "modifiers", BAR_MODIFIER, { 0 } },
     { "'+", "", BAR_MODIFIER, { 0 } },
-    { "end", "", __CALL, { 82 } },
+    { "end", "", __CALL, { 84 } },
 };
 static cmdp_token tokens_BAR_POSITION[2] = {
-    { "'top", "position", __CALL, { 83 } },
-    { "'bottom", "position", __CALL, { 84 } },
+    { "'top", "position", __CALL, { 85 } },
+    { "'bottom", "position", __CALL, { 86 } },
 };
 static cmdp_token tokens_COLOR_BORDER[1] = {
     { "word", "border", COLOR_BACKGROUND, { 0 } },
 };
 static cmdp_token tokens_COLOR_SINGLE[1] = {
-    { "word", "color", __CALL, { 85 } },
+    { "word", "color", __CALL, { 87 } },
 };
 static cmdp_token tokens_FAKE_OUTPUTS[1] = {
-    { "string", "outputs", __CALL, { 86 } },
+    { "string", "outputs", __CALL, { 88 } },
 };
 static cmdp_token tokens_MODE_BINDING[20] = {
     { "'--release", "release", MODE_BINDING, { 0 } },
@@ -289,29 +297,29 @@ static cmdp_token tokens_MODE_BINDING[20] = {
     { "word", "key", MODE_BINDCOMMAND, { 0 } },
 };
 static cmdp_token tokens_NO_FOCUS_END[1] = {
-    { "end", "", __CALL, { 87 } },
+    { "end", "", __CALL, { 89 } },
 };
 static cmdp_token tokens_BAR_BINDSYM[2] = {
     { "'--release", "release", BAR_BINDSYM, { 0 } },
     { "word", "button", BAR_BINDSYM_COMMAND, { 0 } },
 };
 static cmdp_token tokens_BAR_VERBOSE[1] = {
-    { "word", "value", __CALL, { 88 } },
+    { "word", "value", __CALL, { 90 } },
 };
 static cmdp_token tokens_BINDCOMMAND[5] = {
     { "'--release", "release", BINDCOMMAND, { 0 } },
     { "'--border", "border", BINDCOMMAND, { 0 } },
     { "'--whole-window", "whole_window", BINDCOMMAND, { 0 } },
     { "'--exclude-titlebar", "exclude_titlebar", BINDCOMMAND, { 0 } },
-    { "string", "command", __CALL, { 89 } },
+    { "string", "command", __CALL, { 91 } },
 };
 static cmdp_token tokens_IGNORE_LINE[1] = {
     { "line", "", INITIAL, { 0 } },
 };
 static cmdp_token tokens_TITLE_ALIGN[3] = {
-    { "'left", "alignment", __CALL, { 90 } },
-    { "'center", "alignment", __CALL, { 91 } },
-    { "'right", "alignment", __CALL, { 92 } },
+    { "'left", "alignment", __CALL, { 92 } },
+    { "'center", "alignment", __CALL, { 93 } },
+    { "'right", "alignment", __CALL, { 94 } },
 };
 static cmdp_token tokens_BAR_COLORS[15] = {
     { "end", "", BAR_COLORS, { 0 } },
@@ -331,19 +339,19 @@ static cmdp_token tokens_BAR_COLORS[15] = {
     { "'}", "", BAR, { 0 } },
 };
 static cmdp_token tokens_BAR_OUTPUT[1] = {
-    { "string", "output", __CALL, { 93 } },
+    { "string", "output", __CALL, { 95 } },
 };
 static cmdp_token tokens_COLOR_TEXT[1] = {
     { "word", "text", COLOR_INDICATOR, { 0 } },
 };
 static cmdp_token tokens_FOR_WINDOW[1] = {
-    { "'[", "", __CALL, { 94 } },
+    { "'[", "", __CALL, { 96 } },
 };
 static cmdp_token tokens_IPC_SOCKET[1] = {
-    { "string", "path", __CALL, { 95 } },
+    { "string", "path", __CALL, { 97 } },
 };
 static cmdp_token tokens_SHOW_MARKS[1] = {
-    { "word", "value", __CALL, { 96 } },
+    { "word", "value", __CALL, { 98 } },
 };
 static cmdp_token tokens_CRITERION[1] = {
     { "'=", "", CRITERION_STR, { 0 } },
@@ -357,15 +365,15 @@ static cmdp_token tokens_WORKSPACE[1] = {
 };
 static cmdp_token tokens_BARBRACE[2] = {
     { "end", "", BARBRACE, { 0 } },
-    { "'{", "", __CALL, { 97 } },
+    { "'{", "", __CALL, { 99 } },
 };
 static cmdp_token tokens_BAR_FONT[1] = {
-    { "string", "font", __CALL, { 98 } },
+    { "string", "font", __CALL, { 100 } },
 };
 static cmdp_token tokens_BAR_MODE[3] = {
-    { "'dock", "mode", __CALL, { 99 } },
-    { "'hide", "mode", __CALL, { 100 } },
-    { "'invisible", "mode", __CALL, { 101 } },
+    { "'dock", "mode", __CALL, { 101 } },
+    { "'hide", "mode", __CALL, { 102 } },
+    { "'invisible", "mode", __CALL, { 103 } },
 };
 static cmdp_token tokens_CRITERIA[13] = {
     { "'class", "ctype", CRITERION, { 0 } },
@@ -378,16 +386,16 @@ static cmdp_token tokens_CRITERIA[13] = {
     { "'title", "ctype", CRITERION, { 0 } },
     { "'urgent", "ctype", CRITERION, { 0 } },
     { "'workspace", "ctype", CRITERION, { 0 } },
-    { "'tiling", "ctype", __CALL, { 102 } },
-    { "'floating", "ctype", __CALL, { 103 } },
-    { "']", "", __CALL, { 104 } },
+    { "'tiling", "ctype", __CALL, { 104 } },
+    { "'floating", "ctype", __CALL, { 105 } },
+    { "']", "", __CALL, { 106 } },
 };
 static cmdp_token tokens_MODENAME[2] = {
     { "'--pango_markup", "pango_markup", MODENAME, { 0 } },
-    { "word", "modename", __CALL, { 105 } },
+    { "word", "modename", __CALL, { 107 } },
 };
 static cmdp_token tokens_NO_FOCUS[1] = {
-    { "'[", "", __CALL, { 106 } },
+    { "'[", "", __CALL, { 108 } },
 };
 static cmdp_token tokens_BINDING[20] = {
     { "'--release", "release", BINDING, { 0 } },
@@ -468,17 +476,17 @@ static cmdp_token tokens_INITIAL[54] = {
     { "'client.placeholder", "colorclass", COLOR_BORDER, { 0 } },
 };
 static cmdp_token tokens_ASSIGN[1] = {
-    { "'[", "", __CALL, { 107 } },
+    { "'[", "", __CALL, { 109 } },
 };
 static cmdp_token tokens_BAR_ID[1] = {
-    { "word", "bar_id", __CALL, { 108 } },
+    { "word", "bar_id", __CALL, { 110 } },
 };
 static cmdp_token tokens_EXEC[2] = {
     { "'--no-startup-id", "no_startup_id", EXEC, { 0 } },
-    { "string", "command", __CALL, { 109 } },
+    { "string", "command", __CALL, { 111 } },
 };
 static cmdp_token tokens_FONT[1] = {
-    { "string", "font", __CALL, { 110 } },
+    { "string", "font", __CALL, { 112 } },
 };
 static cmdp_token tokens_MODE[8] = {
     { "end", "", MODE, { 0 } },
@@ -490,7 +498,7 @@ static cmdp_token tokens_MODE[8] = {
     { "'bind", "bindtype", MODE_BINDING, { 0 } },
     { "'}", "", INITIAL, { 0 } },
 };
-static cmdp_token tokens_BAR[27] = {
+static cmdp_token tokens_BAR[28] = {
     { "end", "", BAR, { 0 } },
     { "error", "", BAR, { 0 } },
     { "'#", "", BAR_IGNORE_LINE, { 0 } },
@@ -513,13 +521,14 @@ static cmdp_token tokens_BAR[27] = {
     { "'separator_symbol", "", BAR_SEPARATOR_SYMBOL, { 0 } },
     { "'binding_mode_indicator", "", BAR_BINDING_MODE_INDICATOR, { 0 } },
     { "'workspace_buttons", "", BAR_WORKSPACE_BUTTONS, { 0 } },
+    { "'workspace_min_width", "", BAR_WORKSPACE_MIN_WIDTH, { 0 } },
     { "'strip_workspace_numbers", "", BAR_STRIP_WORKSPACE_NUMBERS, { 0 } },
     { "'strip_workspace_name", "", BAR_STRIP_WORKSPACE_NAME, { 0 } },
     { "'verbose", "", BAR_VERBOSE, { 0 } },
     { "'colors", "", BAR_COLORS_BRACE, { 0 } },
-    { "'}", "", __CALL, { 111 } },
+    { "'}", "", __CALL, { 113 } },
 };
-static cmdp_token_ptr tokens[95] = {
+static cmdp_token_ptr tokens[97] = {
     { tokens_FORCE_DISPLAY_URGENCY_HINT_MS, 2 },
     { tokens_FLOATING_MAXIMUM_SIZE_HEIGHT, 1 },
     { tokens_FLOATING_MINIMUM_SIZE_HEIGHT, 1 },
@@ -527,12 +536,14 @@ static cmdp_token_ptr tokens[95] = {
     { tokens_FLOATING_MAXIMUM_SIZE_WIDTH, 1 },
     { tokens_FLOATING_MINIMUM_SIZE_WIDTH, 1 },
     { tokens_BAR_BINDING_MODE_INDICATOR, 1 },
+    { tokens_BAR_WORKSPACE_MIN_WIDTH_PX, 2 },
     { tokens_FOCUS_ON_WINDOW_ACTIVATION, 1 },
     { tokens_FORCE_DISPLAY_URGENCY_HINT, 1 },
     { tokens_BAR_STRIP_WORKSPACE_NAME, 1 },
     { tokens_DEFAULT_BORDER_PIXELS_PX, 2 },
     { tokens_WORKSPACE_BACK_AND_FORTH, 1 },
     { tokens_ASSIGN_WORKSPACE_NUMBER, 1 },
+    { tokens_BAR_WORKSPACE_MIN_WIDTH, 1 },
     { tokens_FLOATING_MAXIMUM_SIZE_X, 1 },
     { tokens_FLOATING_MINIMUM_SIZE_X, 1 },
     { tokens_POPUP_DURING_FULLSCREEN, 3 },
@@ -574,7 +585,7 @@ static cmdp_token_ptr tokens[95] = {
     { tokens_COLOR_INDICATOR, 2 },
     { tokens_DISABLE_RANDR15, 1 },
     { tokens_DEFAULT_BORDER, 4 },
-    { tokens_FOCUS_WRAPPING, 13 },
+    { tokens_FOCUS_WRAPPING, 14 },
     { tokens_FORCE_XINERAMA, 1 },
     { tokens_ASSIGN_OUTPUT, 1 },
     { tokens_CRITERION_STR, 1 },
@@ -614,5 +625,5 @@ static cmdp_token_ptr tokens[95] = {
     { tokens_EXEC, 2 },
     { tokens_FONT, 1 },
     { tokens_MODE, 8 },
-    { tokens_BAR, 27 },
+    { tokens_BAR, 28 },
 };
