@@ -528,6 +528,36 @@ void dump_node(yajl_gen gen, struct Con *con, bool inplace_restart) {
     else
         y(null);
 
+    ystr("window_type");
+    if (con->window) {
+        if (con->window->window_type == A__NET_WM_WINDOW_TYPE_NORMAL) {
+            ystr("normal");
+        } else if (con->window->window_type == A__NET_WM_WINDOW_TYPE_DOCK) {
+            ystr("dock");
+        } else if (con->window->window_type == A__NET_WM_WINDOW_TYPE_DIALOG) {
+            ystr("dialog");
+        } else if (con->window->window_type == A__NET_WM_WINDOW_TYPE_UTILITY) {
+            ystr("utility");
+        } else if (con->window->window_type == A__NET_WM_WINDOW_TYPE_TOOLBAR) {
+            ystr("toolbar");
+        } else if (con->window->window_type == A__NET_WM_WINDOW_TYPE_SPLASH) {
+            ystr("splash");
+        } else if (con->window->window_type == A__NET_WM_WINDOW_TYPE_MENU) {
+            ystr("menu");
+        } else if (con->window->window_type == A__NET_WM_WINDOW_TYPE_DROPDOWN_MENU) {
+            ystr("dropdown_menu");
+        } else if (con->window->window_type == A__NET_WM_WINDOW_TYPE_POPUP_MENU) {
+            ystr("popup_menu");
+        } else if (con->window->window_type == A__NET_WM_WINDOW_TYPE_TOOLTIP) {
+            ystr("tooltip");
+        } else if (con->window->window_type == A__NET_WM_WINDOW_TYPE_NOTIFICATION) {
+            ystr("notification");
+        } else {
+            ystr("unknown");
+        }
+    } else
+        y(null);
+
     if (con->window && !inplace_restart) {
         /* Window properties are useless to preserve when restarting because
          * they will be queried again anyway. However, for i3-save-tree(1),
@@ -789,6 +819,9 @@ static void dump_bar_config(yajl_gen gen, Barconfig *config) {
     ystr("workspace_buttons");
     y(bool, !config->hide_workspace_buttons);
 
+    ystr("workspace_min_width");
+    y(integer, config->workspace_min_width);
+
     ystr("strip_workspace_numbers");
     y(bool, config->strip_workspace_numbers);
 
@@ -873,6 +906,9 @@ IPC_HANDLER(get_workspaces) {
             assert(ws->type == CT_WORKSPACE);
             y(map_open);
 
+            ystr("id");
+            y(integer, (uintptr_t)ws);
+
             ystr("num");
             y(integer, ws->num);
 
